import React from 'react';
import { monaco } from '@codingame/monaco-editor-wrapper';
import { IEditorOptions } from 'vscode/service-override/modelEditor';
import './style';
type KeyBindingsMode = 'classic' | 'vim' | 'emacs';
export declare function defaultRestoreViewState(editor: monaco.editor.IStandaloneCodeEditor, model: monaco.editor.ITextModel): void;
export declare function defaultSaveViewState(editor: monaco.editor.IStandaloneCodeEditor, model: monaco.editor.ITextModel): void;
export interface MonacoEditorProps {
    /**
     * - auto means the editor will grow or shring base on the content
     * - Any other value is just used as is
     *
     * default: 100%
     */
    height?: 'auto' | string | number;
    /**
     * Max height when in height: auto mode
     */
    maxHeight?: number;
    /**
     * Max height when in height: auto mode
     */
    minHeight?: number;
    value?: string;
    programmingLanguage?: string;
    fileUri?: string;
    options?: monaco.editor.IStandaloneEditorConstructionOptions;
    onChange?: (value: string, event: monaco.editor.IModelContentChangedEvent) => void;
    markers?: monaco.editor.IMarkerData[];
    keyBindingsMode?: KeyBindingsMode;
    /**
     * Called when the editor will switch to another model
     *
     * Default to store is into a Map<fileUri, viewState>
     */
    saveViewState?: (editor: monaco.editor.IStandaloneCodeEditor, model: monaco.editor.ITextModel) => void;
    /**
     * Called when the editor just switch to a model
     *
     * Default to using the Map<fileUri, viewState>
     */
    restoreViewState?: (editor: monaco.editor.IStandaloneCodeEditor, model: monaco.editor.ITextModel) => void;
    /**
     * Called when the user do a ctrl+click on a reference to another model
     * The returned editor should already contain the model before this function returns
     *
     * Default is opening a new editor in a popup
     */
    onEditorOpenRequest?: (model: monaco.editor.ITextModel, options: IEditorOptions | undefined, source: monaco.editor.ICodeEditor, sideBySide?: boolean) => Promise<monaco.editor.ICodeEditor | null>;
    /**
     * if true, the models created by the component will be disposed when they are no longer displayed in the editor
     * if false, the models will be kept and re-used the next time the same uri is provided
     */
    disposeModels?: boolean;
}
declare const _default: React.ForwardRefExoticComponent<MonacoEditorProps & React.RefAttributes<monaco.editor.IStandaloneCodeEditor>>;
export default _default;
